#[non_exhaustive]pub enum CslParseErrorKind {
}Expand description
What went wrong while parsing a CSL style. Paired with a byte offset inside
a CslParseError.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
MalformedXml(String)
The input is not well-formed XML.
UnexpectedRoot(String)
The root element is not <style>.
ForeignNamespace(String)
The <style> root is in a namespace other than the CSL namespace.
MissingVersion
<style> lacks the required version attribute.
MissingClass
<style> lacks the required class attribute.
UnknownClass(String)
class is neither in-text nor note.
UnsupportedVersion(String)
version is not a supported CSL style version.
MissingMacroName
A <macro> lacks the required name attribute.
MissingLayout
A <citation> or <bibliography> lacks its required <layout>.
TextWithoutSource
A <text> element selects none of variable/macro/term/value.
TextWithMultipleSources
A <text> element selects more than one source attribute.
InvalidChooseOrder
A <choose> has no leading <if> or branches in the wrong order.
UnsupportedElement(String)
A rendering element name is not part of the supported CSL subset.
Implementations